# ifndef yyImplMapping
# define yyImplMapping

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* ImplMapping_Exit) ARGS ((void));

extern void ImplMapping ARGS ((tTree t));

extern void BeginImplMapping ARGS ((void));
extern void CloseImplMapping ARGS ((void));

# endif
